/*
 * Tasks.java
 */

package com.builder.uk.todotasks;

import java.io.IOException;
import java.util.List;

/**
 * Tasks interface to be implemented by any Tasks bean
 * @author dj
 */
public interface Tasks {
        
    /**
     * Creates a new unique Task
     * @return a newly created Task instance
     * @throws java.io.IOException thrown when an IO error occurs
     */
    public Task createTask() throws IOException;
    
    /**
     * Get a list of all Task ids
     * @return A List of Long Task ids
     * @throws java.io.IOException Thrown when an IO error occurs
     */
    public List<Long> getTaskIds() throws IOException;
    
    /**
     * Get the Task associated with the id
     * @return null if no Task exists with that id
     * @param taskId task id
     * @throws java.io.IOException thrown if an IO error occurs
     */
    public Task getTask(Long taskId) throws IOException;
    
    /**
     * Get the number of Tasks
     * @return number of tasks
     */
    public int getTaskCount();
    
    /**
     * Removes a Task
     * @param taskId id of task to be removed
     * @throws java.io.IOException thrown if an IO error occurs
     */
    public void removeTask(Long taskId) throws IOException;
    
    /**
     * Update Task, called when the contents of the Task has been updated
     * @param t Task that has been updated
     * @throws java.io.IOException thrown if an IO error occurs
     */
    void update(Task t) throws IOException;
    
    /**
     * Closes the Tasks instance.
     * @throws java.io.IOException thrown if an IO error occurs
     */
    void close() throws IOException;
    
    /**
     * Registers TasksListener to receive events.
     *
     * @param listener The listener to register.
     */
    public void addTasksListener(TasksListener listener);
    
    /**
     * Removes TasksListener from the list of listeners.
     *
     * @param listener The listener to remove.
     */
    void removeTasksListener(TasksListener listener);
    
}
