/*
 * TasksFactory.java
 */

package com.builder.uk.todotasks;

import java.io.IOException;
import java.lang.UnsupportedOperationException;

/**
 * Factory for creating Tasks instances.
 */
public class TasksFactory {
    
    /**
     * Type of Task enum
     */
    public enum TasksType { 
        /**
         * Create a non-persistent memory based Tasks instance
         */
        MEMORY, 
        /**
         * Create a JDBM based Tasks instance
         */
        JDBM };
    
    /**
     * Creates a new Tasks implementing instance based on the requested type
     * @param t Type of Tasks to be created
     * @throws java.io.IOException Thrown if an IO error occurs in creating the Tasks instance
     * @return Tasks instance
     */
    public static Tasks createTasks(TasksType t) throws IOException {
        switch(t) {
            case MEMORY:
                return new TasksMemoryImpl();
            case JDBM:
                return new TasksJDBMImpl();
        }
        
        throw new UnsupportedOperationException("No such type of Tasks");
    }
    
    private static Tasks currentTasks;
    
    public static Tasks getTasks()
    {
        if(currentTasks==null)
        {
            try {
                currentTasks=createTasks(TasksType.JDBM);
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }
        return currentTasks;
    }
}
