/*
 * TasksMemoryImpl.java
 *
 */

package com.builder.uk.todotasks;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import jdbm.RecordManager;
import jdbm.htree.HTree;

/**
 * Memory based implementation of Tasks
 * @author Dj
 */
public class TasksMemoryImpl implements Tasks {
    
    RecordManager recman;
    HTree htreetable;
    
    Long taskid=1000L;
    
    /** Creates a new instance of TodoBean */
    public TasksMemoryImpl() {
    }

    /**
     * Holds value of property tasks.
     */
    private Map<Long, Task> tasks=new HashMap<Long,Task>();
    
    private Long generateTaskId()
    {
        synchronized (taskid)
        {
            return taskid++;
        }
    }
    
    public List<Long> getTaskIds()
    {
        return new ArrayList<Long>(tasks.keySet());
    }
    
    public Task createTask()
    {
        Task toDoTask=new Task();
        Long l=generateTaskId();
        toDoTask.setTaskId(l);
        toDoTask.setPriority(Priority.NONE);
        toDoTask.setName("New Task");
        toDoTask.setDonePercent(0);
        tasks.put(l,toDoTask);
        fireTasksListenerTasksChanged(new TasksEvent(TasksEvent.TasksEventType.NEW,toDoTask));
        return toDoTask;
    }
    
    public void removeTask(Long id)
    {
        tasks.remove(id);
        fireTasksListenerTasksChanged(new TasksEvent(TasksEvent.TasksEventType.DELETED,id));
    }
    
    public int getTaskCount()
    {
        return tasks.size();
    }

     public Task getTask(Long id) {
        return tasks.get(id);
    }

    public void update(Task t)
    {
        fireTasksListenerTasksChanged(new TasksEvent(TasksEvent.TasksEventType.CHANGED,t));
    }
    
    /**
     * Utility field used by event firing mechanism.
     */
    private javax.swing.event.EventListenerList listenerList =  null;

    /**
     * Registers TasksListener to receive events.
     * @param listener The listener to register.
     */
    public synchronized void addTasksListener(com.builder.uk.todotasks.TasksListener listener) {
        if (listenerList == null ) {
            listenerList = new javax.swing.event.EventListenerList();
        }
        listenerList.add (com.builder.uk.todotasks.TasksListener.class, listener);
    }

    /**
     * Removes TasksListener from the list of listeners.
     * @param listener The listener to remove.
     */
    public synchronized void removeTasksListener(com.builder.uk.todotasks.TasksListener listener) {
        listenerList.remove (com.builder.uk.todotasks.TasksListener.class, listener);
    }

    /**
     * Notifies all registered listeners about the event.
     * 
     * @param event The event to be fired
     */
    private void fireTasksListenerTasksChanged(com.builder.uk.todotasks.TasksEvent event) {
        if (listenerList == null) return;
        Object[] listeners = listenerList.getListenerList ();
        for (int i = listeners.length - 2; i >= 0; i -= 2) {
            if (listeners[i]==com.builder.uk.todotasks.TasksListener.class) {
                ((com.builder.uk.todotasks.TasksListener)listeners[i+1]).tasksChanged (event);
            }
        }
    }

    public void close() throws IOException {
        // Nothing to do here
    }



   
}
